"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createBridgeCodeGenerator = void 0;
const json5_1 = __importDefault(require("json5"));
const js_yaml_1 = __importDefault(require("js-yaml"));
function createBridgeCodeGenerator(source, query) {
    return () => {
        const data = convert(source, query.lang);
        let value = JSON.parse(data);
        if (query.locale && typeof query.locale === 'string') {
            value = Object.assign({}, { [query.locale]: value });
        }
        return JSON.stringify(value)
            .replace(/\u2028/g, '\\u2028')
            .replace(/\u2029/g, '\\u2029')
            .replace(/\\/g, '\\\\')
            .replace(/\u0027/g, '\\u0027');
    };
}
exports.createBridgeCodeGenerator = createBridgeCodeGenerator;
function convert(source, lang) {
    const value = Buffer.isBuffer(source) ? source.toString() : source;
    switch (lang) {
        case 'yaml':
        case 'yml':
            const data = js_yaml_1.default.load(value);
            return JSON.stringify(data, undefined, '\t');
        case 'json5':
            return JSON.stringify(json5_1.default.parse(value));
        default:
            return value;
    }
}
